@@ -1,11 +1,12 @@
 import requests
 import json
 
-from ..response import ok, error
+from ..MuviBase import MuviBase
 
 
-class CardToken:
-    def __init__(self, url: str, private_key: str, public_key: str):
+class CardToken(MuviBase):
+    def __init__(self, processor: str, url: str, private_key: str, public_key: str):
+        super().__init__(processor)
         self.url = url
         self.private_key = private_key
         self.public_key = public_key
@@ -28,5 +29,5 @@ class CardToken:
         self.headers['apikey'] = self.private_key
         response = r.json()
         if r.status_code > 299:
-            return error(response)
-        return ok(response)
+            return self.error(response, message=response['error_type'], status=r.status_code)
+        return self.ok(response, status=r.status_code)
