@@ -19,22 +19,23 @@ class DecidirSDK:
         self.merchant_name = merchant['name']
         self.site_id = credentials_local['site_id']
         self.site_id_cadena = credentials_cadena['site_id']
+        self.processor = 'decidir'
 
     def customer(self):
-        return Customer(self.url, self.private_key, self.public_key)
+        return Customer(self.processor, self.url, self.private_key, self.public_key)
     
     def card(self):
-        return Card(self.url, self.private_key, self.public_key)
+        return Card(self.processor, self.url, self.private_key, self.public_key)
 
     def card_token(self):
-        return CardToken(self.url, self.private_key, self.public_key)
+        return CardToken(self.processor, self.url, self.private_key, self.public_key)
 
     def payment(self):
-        return Payment(self.url, self.private_key, self.public_key, self.merchant_name, self.site_id,
+        return Payment(self.processor, self.url, self.private_key, self.public_key, self.merchant_name, self.site_id,
                        self.site_id_cadena)
 
     def refund(self):
-        return Refund(self.url, self.private_key, self.public_key)
+        return Refund(self.processor, self.url, self.private_key, self.public_key)
 
     def ok(self):
         return self.private_key is not None
